/***********************************************
 * SITE: ANIMATE ELEMENT
 ***********************************************/
(function ($) {

	'use strict';

	VLTJS.animatedBlock = {
		init: function () {
			var el = $('.vlt-animate-element'),
				prefix = 'animate__';
			if (VLTJS.body.hasClass('page-template-template-fullpage-slider')) {
				VLTJS.window.on('vlt.change-slide', function () {
					el.each(function () {
						var $this = $(this);
						var animationName = $this.data('animation-name');
						$this.removeClass(prefix + 'animated').removeClass(prefix + animationName);
						if ($this.parents('.vlt-section').hasClass('active')) {
							$this.addClass(prefix + 'animated').addClass(prefix + animationName);
						}
					});
				});
			} else {
				el.each(function () {
					var $this = $(this);
					$this.one('inview', function () {
						var animationName = $this.data('animation-name');
						$this.addClass(prefix + 'animated').addClass(prefix + animationName);
					});
				});
			}
		}
	};
	VLTJS.animatedBlock.init();
})(jQuery);
/***********************************************
 * SITE: FULLPAGE SLIDER
 ***********************************************/
(function ($) {

	'use strict';

	VLTJS.fullpageSlider = {
		init: function () {

			var slider = $('.vlt-fullpage-slider');

			if (!slider.length) {
				return;
			}

			if (typeof $.fn.pagepiling == 'undefined') {
				return;
			}

			var progress_bar = slider.find('.vlt-fullpage-slider-dots'),
				numbers = slider.find('.vlt-fullpage-slider-numbers'),
				loop_top = slider.data('loop-top') ? true : false,
				loop_bottom = slider.data('loop-bottom') ? true : false,
				speed = slider.data('speed') || 800,
				anchors = [];

			VLTJS.body.css('overflow', 'hidden');
			VLTJS.html.css('overflow', 'hidden');

			slider.find('[data-anchor]').each(function () {
				anchors.push($(this).data('anchor'));
			});

			function vlthemes_navbar_solid() {
				if (slider.find('.pp-section.active').scrollTop() > 0) {
					$('.vlt-navbar').addClass('vlt-navbar--solid');
				} else {
					$('.vlt-navbar').removeClass('vlt-navbar--solid');
				}
			}
			vlthemes_navbar_solid();

			function vlthemes_show_navigation() {
				progress_bar.find('a:first-child').addClass('active').end().addClass('is-show');
			}

			function vlthemes_page_brightness() {
				var section = slider.find('.vlt-section.active');
				switch (section.data('brightness')) {
					case 'light':
						VLTJS.html.removeClass('is-light-copyright- is-dark').addClass('is-light');
						break;
					case 'dark':
						VLTJS.html.removeClass('is-light-copyright is-light').addClass('is-dark');
						break;
					case 'light-copyright':
						VLTJS.html.removeClass('is-dark is-light').addClass('is-light-copyright');
						break;
				}
			}

			numbers.html(slider.find('.vlt-section.active').index() + 1);

			slider.pagepiling({
				menu: '.vlt-offcanvas-menu ul.sf-menu, .vlt-fullpage-slider-dots',
				scrollingSpeed: speed,
				loopTop: loop_top,
				loopBottom: loop_bottom,
				anchors: anchors,
				sectionSelector: '.vlt-section',
				navigation: false,
				afterRender: function () {
					vlthemes_show_navigation();
					vlthemes_page_brightness();
					numbers.html(slider.find('.vlt-section.active').index() + 1);
					VLTJS.window.trigger('vlt.change-slide');
				},
				onLeave: function (index, nextIndex, direction) {
					vlthemes_page_brightness();
					numbers.html(slider.find('.vlt-section.active').index() + 1);
					VLTJS.window.trigger('vlt.change-slide');
				},
				afterLoad: function (anchorLink, index) {
					vlthemes_navbar_solid();
				}
			});

			slider.find('.pp-scrollable').on('scroll', function () {
				var scrollTop = $(this).scrollTop();
				if (scrollTop > 0) {
					$('.vlt-navbar').addClass('vlt-navbar--solid');
				} else {
					$('.vlt-navbar').removeClass('vlt-navbar--solid');
				}
			});

		}

	};

	VLTJS.fullpageSlider.init();

})(jQuery);
/***********************************************
 * SITE: LOCALES
 ***********************************************/
(function ($) {

	'use strict';

	VLTJS.locales = {
		init: function () {

			var navbarLocalesLink = $('.vlt-offcanvas-menu__locales .glink'),
				keyValue = document['cookie'].match('(^|;) ?googtrans=([^;]*)(;|$)');

			keyValue = keyValue ? keyValue[2].split('/')[2] : null;

			function set_default_locales() {
				navbarLocalesLink.removeClass('is-active');
				navbarLocalesLink.each(function (index) {
					var currentLink = $(this),
						attribute = currentLink.attr('onclick');

					if (keyValue !== null) {
						if (attribute.indexOf(keyValue) !== -1) {
							currentLink.addClass('is-active');
						}
					} else {
						navbarLocalesLink.eq(0).addClass('is-active');
					}
				});

			}
			set_default_locales();

			navbarLocalesLink.on('click', function () {
				navbarLocalesLink.removeClass('is-active');
				$(this).addClass('is-active');
			});
		}
	};
	VLTJS.locales.init();
})(jQuery);
/***********************************************
 * SITE: NAVBAR
 ***********************************************/
(function ($) {
	'use strict';

	var navbarMain = $('.vlt-navbar--main'),
		navbarContacts = $('.vlt-navbar-contacts'),
		navbarHeight = navbarMain.outerHeight(),
		navbarMainOffset = 0;

	// fake navbar
	var navbarFake = $('<div class="vlt-fake-navbar">').hide();

	// fixed navbar
	function _fixed_navbar() {
		navbarMain.addClass('vlt-navbar--fixed');
		navbarFake.show();
		// add solid color
		if (navbarMain.hasClass('vlt-navbar--transparent') && navbarMain.hasClass('vlt-navbar--sticky')) {
			navbarMain.addClass('vlt-navbar--solid');
		}
	}

	function _unfixed_navbar() {
		navbarMain.removeClass('vlt-navbar--fixed');
		navbarFake.hide();
		// remove solid color
		if (navbarMain.hasClass('vlt-navbar--transparent') && navbarMain.hasClass('vlt-navbar--sticky')) {
			navbarMain.removeClass('vlt-navbar--solid');
		}
	}

	function _on_scroll_navbar() {
		if (VLTJS.window.scrollTop() > navbarMainOffset) {
			_fixed_navbar();
		} else {
			_unfixed_navbar();
		}
	}

	if (navbarMain.hasClass('vlt-navbar--sticky')) {
		VLTJS.window.on('scroll resize', _on_scroll_navbar);
		_on_scroll_navbar();
		// append fake navbar
		navbarMain.after(navbarFake);
		// fake navbar height after resize
		navbarFake.height(navbarHeight);
		VLTJS.debounceResize(function () {
			navbarFake.height(navbarHeight);
		});
	}

	// add sep
	navbarContacts.find('li + li').before('<li class="sep">/</li>');

})(jQuery);
/***********************************************
 * SITE: OFFCANVAS MENU
 ***********************************************/
(function ($) {

	'use strict';

	var menuIsOpen = false;

	VLTJS.menuOffcanvas = {
		config: {
			easing: 'power2.out'
		},
		init: function () {
			var menu = $('.vlt-offcanvas-menu'),
				locales = $('.vlt-offcanvas-menu__locales'),
				footer = $('.vlt-offcanvas-menu__footer > div'),
				navigation = menu.find('ul.sf-menu'),
				navigationItem = navigation.find('>li'),
				menuOpen = $('.js-offcanvas-menu-open'),
				menuClose = $('.js-offcanvas-menu-close'),
				siteOverlay = $('.vlt-site-overlay');

			if (typeof $.fn.superclick !== 'undefined') {
				navigation.superclick({
					delay: 300,
					cssArrows: false,
					animation: {
						opacity: 'show',
						height: 'show'
					},
					animationOut: {
						opacity: 'hide',
						height: 'hide'
					},
				});
			}

			menuOpen.on('click', function (e) {
				e.preventDefault();
				if (!menuIsOpen) {
					VLTJS.menuOffcanvas.open_menu(menu, siteOverlay, navigation, locales, footer, menuOpen, menuClose);
				}
			});

			menuClose.on('click', function (e) {
				e.preventDefault();
				if (menuIsOpen) {
					VLTJS.menuOffcanvas.close_menu(menu, siteOverlay, navigation, locales, footer, menuOpen, menuClose);
				}
			});

			siteOverlay.on('click', function (e) {
				e.preventDefault();
				if (menuIsOpen) {
					VLTJS.menuOffcanvas.close_menu(menu, siteOverlay, navigation, locales, footer, menuOpen, menuClose);
				}
			});

			VLTJS.document.keyup(function (e) {
				if (e.keyCode === 27 && menuIsOpen) {
					e.preventDefault();
					VLTJS.menuOffcanvas.close_menu(menu, siteOverlay, navigation, locales, footer, menuOpen, menuClose);
				}
			});

			// Close after click to anchor.
			navigationItem.filter('[data-menuanchor]').on('click', 'a', function () {
				if (menuIsOpen) {
					VLTJS.menuOffcanvas.close_menu(menu, siteOverlay, navigation, locales, footer, menuOpen, menuClose);
				}
			});

		},
		open_menu: function (menu, siteOverlay, navigation, locales, footer, menuOpen, menuClose) {
			menuIsOpen = true;

			menuOpen.addClass('vlt-menu-burger--opened');
			menuClose.addClass('vlt-menu-burger--opened');

			if (typeof gsap != 'undefined') {
				gsap.timeline({
						defaults: {
							ease: this.config.easing
						}
					})
					// set overflow for html
					.set(VLTJS.html, {
						overflow: 'hidden'
					})
					// overlay animation
					.to(siteOverlay, .3, {
						autoAlpha: 1,
					})
					// menu animation
					.fromTo(menu, .6, {
						x: '100%',
					}, {
						x: 0,
						visibility: 'visible'
					}, '-=.3')
					// locales animation
					.fromTo(locales, .3, {
						y: 50,
						autoAlpha: 0
					}, {
						y: 0,
						autoAlpha: 1
					})
					// navigation
					.fromTo(navigation, .3, {
						y: 50,
						autoAlpha: 0
					}, {
						y: 0,
						autoAlpha: 1
					}, '-=.15')
					// footer animation
					.fromTo(footer, .3, {
						y: 50,
						autoAlpha: 0
					}, {
						y: 0,
						autoAlpha: 1,
						stagger: {
							each: .1,
							from: 'start',
						}
					}, '-=.15');
			}
		},
		close_menu: function (menu, siteOverlay, navigation, locales, footer, menuOpen, menuClose) {
			menuIsOpen = false;

			menuOpen.removeClass('vlt-menu-burger--opened');
			menuClose.removeClass('vlt-menu-burger--opened');

			if (typeof gsap != 'undefined') {
				gsap.timeline({
						defaults: {
							ease: this.config.easing
						}
					})
					// set overflow for html
					.set(VLTJS.html, {
						overflow: 'inherit'
					})
					// footer animation
					.to(footer, .3, {
						y: 50,
						autoAlpha: 0,
						stagger: {
							each: .1,
							from: 'end',
						}
					})
					// navigation
					.to(navigation, .3, {
						y: 50,
						autoAlpha: 0,
					}, '-=.15')
					// locales animation
					.to(locales, .3, {
						y: 50,
						autoAlpha: 0,
					}, '-=.15')
					// menu animation
					.to(menu, .6, {
						x: '100%',
					}, '-=.15')
					// set visibility menu after animation
					.set(menu, {
						visibility: 'hidden'
					})
					// overlay animation
					.to(siteOverlay, .3, {
						autoAlpha: 0
					}, '-=.6');
			}
		}
	};
	VLTJS.menuOffcanvas.init();
})(jQuery);
/***********************************************
 * HAYLEY: OTHER SCRIPTS
 ***********************************************/
(function ($) {
	'use strict';

	// Page title offset
	if ($('.vlt-header').hasClass('vlt-header--opaque')) {
		$('.vlt-page-title, .vlt-post--style-single').css('margin-top', -$('.vlt-header--opaque').outerHeight());
	}

	// Widget menu
	if (typeof $.fn.superclick !== 'undefined') {
		$('.widget_pages > ul, .widget_nav_menu ul.menu').superclick({
			delay: 300,
			cssArrows: false,
			animation: {
				opacity: 'show',
				height: 'show'
			},
			animationOut: {
				opacity: 'hide',
				height: 'hide'
			},
		});
	}

	// Fast click
	if (typeof FastClick === 'function') {
		FastClick.attach(document.body);
	}

	// Masonry blog
	$('.masonry').vlt_masonry_grid();

	// Match Height
	$('.vlt-award-item').matchHeight();

	// Material input
	if ($('.vlt-form-group').length) {
		$('.vlt-form-group .vlt-form-control').each(function () {
			if ($(this).val().length > 0 || $(this).attr('placeholder') !== undefined) {
				$(this).closest('.vlt-form-group').addClass('active');
			}
		});
		$('.vlt-form-group .vlt-form-control').focus(function () {
			$(this).closest('.vlt-form-group').addClass('active');
		});
		$('.vlt-form-group .vlt-form-control').blur(function () {
			if ($(this).val() == '' && $(this).attr('placeholder') == undefined) {
				$(this).closest('.vlt-form-group').removeClass('active');
			}
		});
		$('.vlt-form-group .vlt-form-control').change(function () {
			if ($(this).val() == '' && $(this).attr('placeholder') == undefined) {
				$(this).closest('.vlt-form-group').removeClass('active');
			} else {
				$(this).closest('.vlt-form-group').addClass('active');
			}
		});
	}

})(jQuery);
/***********************************************
 * SITE: PRELOADER
 ***********************************************/
(function ($) {
	'use strict';

	var el = $('.vlt-preloader');

	VLTJS.window.on('load', function () {
		if (el.length) {
			el.fadeOut(300);
		}
		VLTJS.window.trigger('vlt.preloader_done');
		VLTJS.html.addClass('vlt-is-page-loaded');
	});

})(jQuery);
/***********************************************
 * WIDGET: CONTACT FORM 7
 ***********************************************/
(function ($) {

	'use strict';

	var VLThemesContactForm7 = function ($scope) {

		// File Input Path
		VLTJS.document.on('change', '.wpcf7-form input[type="file"]', function () {
			var file_field = $(this).closest('.vlt-form-group'),
				path_input = file_field.find('.vlt-form-file-label > span'),
				files = $(this)[0].files,
				file_names = [];
			for (var i = 0; i < files.length; i++) {
				file_names.push(files[i].name);
			}
			path_input.text(file_names.join(', '));
			path_input.trigger('change');
		});

	};

	VLTJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/vlt-contact-form-7.default',
			VLThemesContactForm7
		);
	});

	VLThemesContactForm7();

})(jQuery);
/***********************************************
 * WIDGET: PROGRESS BAR
 ***********************************************/
(function ($) {

	'use strict';

	// check if plugin defined
	if (typeof gsap == 'undefined') {
		return;
	}

	VLTJS.progressBar = {
		init: function ($scope, $) {

			var el = $scope.find('.vlt-progress-bar'),
				final_value = el.data('final-value') || 0,
				animation_duration = el.data('animation-speed') || 0,
				delay = 500,
				obj = {
					count: 0
				};

			if (VLTJS.body.hasClass('page-template-template-fullpage-slider')) {
				VLTJS.progressBar.initProgressBarForSlider(el, obj, animation_duration, final_value, delay);
			} else {
				VLTJS.progressBar.initProgressBar(el, obj, animation_duration, final_value, delay);
			}

		},
		initProgressBar: function (el, obj, animation_duration, final_value, delay) {

			el.one('inview', function () {
				gsap.to(obj, (animation_duration / 1000) / 2, {
					count: final_value,
					delay: delay / 1000,
					onUpdate: function () {
						el.find('.vlt-progress-bar__title > .counter').text(Math.round(obj.count));
					}
				});

				gsap.to(el.find('.vlt-progress-bar__bar > span'), animation_duration / 1000, {
					width: final_value + '%',
					delay: delay / 1000
				});
			});

		},
		initProgressBarForSlider: function (el, obj, animation_duration, final_value, delay) {
			function start() {
				if (el.parents('.vlt-section').hasClass('active')) {

					obj.count = 0;

					el.find('.vlt-progress-bar__title > .counter').text(Math.round(obj.count));

					gsap.set(el.find('.vlt-progress-bar__bar > span'), {
						width: 0
					});

					gsap.to(obj, (animation_duration / 1000) / 2, {
						count: final_value,
						delay: delay / 1000,
						onUpdate: function () {
							el.find('.vlt-progress-bar__title > .counter').text(Math.round(obj.count));
						}
					});

					gsap.to(el.find('.vlt-progress-bar__bar > span'), animation_duration / 1000, {
						width: final_value + '%',
						delay: delay / 1000
					});

				}
			}
			VLTJS.window.on('vlt.change-slide', start);
			start();
		}
	}

	VLTJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/vlt-progress-bar.default',
			VLTJS.progressBar.init
		);
	});

})(jQuery);
/***********************************************
 * WIDGET: PROJECTS SHOWCASE
 ***********************************************/
(function ($) {

	'use strict';

	VLTJS.projectsShowcase = {
		init: function ($scope) {

			// check if plugin defined
			if (typeof Swiper == 'undefined') {
				return;
			}

			var el = $scope.find('.vlt-projects-showcase'),
				slider_container = el.find('.swiper-container');

			new Swiper(slider_container, {
				speed: 1000,
				effect: 'fade',
				slidesPerView: 1,
				navigation: {
					nextEl: el.find('.next'),
					prevEl: el.find('.prev'),
				},
			});

		}
	}

	VLTJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/vlt-projects-showcase.default',
			function ($scope) {
				VLTJS.projectsShowcase.init($scope);
				VLTJS.debounceResize(function () {
					VLTJS.projectsShowcase.init($scope);
				});
			}
		);
	});

})(jQuery);
/***********************************************
 * WIDGET: TESTIMONIAL SLIDER
 ***********************************************/
(function ($) {

	'use strict';

	VLTJS.testimonialSlider = {
		init: function ($scope, $) {
			// check if plugin defined
			if (typeof Swiper == 'undefined') {
				return;
			}
			var el = $scope.find('.vlt-testimonial-slider'),
				sliderContainer = el.find('.swiper-container'),
				speed = el.data('animation-speed') || 1000,
				gap = el.data('gap') || 0,
				loop = el.data('loop') ? true : false;
			new Swiper(sliderContainer, {
				speed: speed,
				spaceBetween: gap,
				grabCursor: true,
				slidesPerView: 1,
				loop: loop,
				navigation: {
					nextEl: $('.vlt-slider-controls--testimonial-slider .next'),
					prevEl: $('.vlt-slider-controls--testimonial-slider .prev'),
				},
				pagination: {
					el: $('.vlt-slider-controls--testimonial-slider .pagination'),
					clickable: false,
					type: 'fraction',
					renderFraction: function (currentClass, totalClass) {
						return '<span class="' + currentClass + '"></span>' +
							'<span class="sep">/</span>' +
							'<span class="' + totalClass + '"></span>';
					}
				}
			});
		}
	};

	VLTJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/vlt-testimonial-slider.default',
			VLTJS.testimonialSlider.init
		);
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/vlt-slider-controls.default',
			VLTJS.testimonialSlider.init
		);
	});

})(jQuery);
/***********************************************
 * WIDGET: TIMELINE SLIDER
 ***********************************************/
(function ($) {

	'use strict';

	VLTJS.timelineSlider = {
		init: function ($scope, $) {
			// check if plugin defined
			if (typeof Swiper == 'undefined') {
				return;
			}
			var el = $scope.find('.vlt-timeline-slider'),
				sliderContainer = el.find('.swiper-container'),
				speed = el.data('animation-speed') || 1000,
				loop = el.data('loop') ? true : false;
			new Swiper(sliderContainer, {
				speed: speed,
				spaceBetween: 0,
				grabCursor: true,
				slidesPerView: 1,
				loop: loop,
				navigation: {
					nextEl: $('.vlt-slider-controls--timeline-slider .next'),
					prevEl: $('.vlt-slider-controls--timeline-slider .prev'),
				},
				pagination: {
					el: $('.vlt-slider-controls--timeline-slider .pagination'),
					clickable: false,
					type: 'fraction',
					renderFraction: function (currentClass, totalClass) {
						return '<span class="' + currentClass + '"></span>' +
							'<span class="sep">/</span>' +
							'<span class="' + totalClass + '"></span>';
					}
				}
			});
		}
	};

	VLTJS.window.on('elementor/frontend/init', function () {
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/vlt-timeline-slider.default',
			VLTJS.timelineSlider.init
		);
		elementorFrontend.hooks.addAction(
			'frontend/element_ready/vlt-slider-controls.default',
			VLTJS.timelineSlider.init
		);
	});

})(jQuery);