<?php

/**
 * @author: VLThemes
 * @version: 1.0
 */

/**
* Theme path image
*/
$theme_path_images = HAYLEY_THEME_DIRECTORY . 'assets/img/';

/**
 * Wrapper for Kirki
 */
if ( ! class_exists( 'VLT_Options' ) ) {
	class VLT_Options {

		private static $default_options = array();

		public static function add_config( $args ) {
			if ( class_exists( 'Kirki' ) && isset( $args ) && is_array( $args ) ) {
				Kirki::add_config( 'hayley_customize', $args );
			}
		}

		public static function add_panel( $name, $args ) {
			if ( class_exists( 'Kirki' ) && isset( $args ) && is_array( $args ) ) {
				Kirki::add_panel( $name, $args );
			}
		}

		public static function add_section( $name, $args ) {
			if ( class_exists( 'Kirki' ) && isset( $args ) && is_array( $args ) ) {
				Kirki::add_section( $name, $args );
			}
		}

		public static function add_field( $args ) {
			if ( isset( $args ) && is_array( $args ) ) {
				if ( class_exists( 'Kirki' ) ) {
					Kirki::add_field( 'hayley_customize', $args );
				}
				if ( isset( $args['settings'] ) && isset( $args['default'] ) ) {
					self::$default_options[$args['settings']] = $args['default'];
				}
			}
		}

		public static function get_option( $name, $default = null ) {
			$value = get_theme_mod( $name, null );

			if ( $value === null ) {
				$value = isset( self::$default_options[$name] ) ? self::$default_options[$name] : null;
			}

			if ( $value === null ) {
				$value = $default;
			}

			return $value;
		}

	}
}

/**
 * Custom get_theme_mod
 */
if ( ! function_exists( 'hayley_get_theme_mod' ) ) {
	function hayley_get_theme_mod( $name = null, $use_acf = null, $postID = null, $acf_name = null ) {

		$value = null;

		if ( $name == null ) {
			return $value;
		}

		// try get value from meta box
		if ( $use_acf ) {
			$value = hayley_get_field( $acf_name ? $acf_name : $name, $postID );
		}

		// get value from options
		if ( $value == null ) {
			if ( class_exists( 'VLT_Options' ) ) {
				$value = VLT_Options::get_option( $name );
			}
		}

		if ( is_archive() || is_search() || is_404() ) {
			if ( class_exists( 'VLT_Options' ) ) {
				$value = VLT_Options::get_option( $name );
			}
		}

		$value = apply_filters( 'hayley/get_theme_mod', $value, $name );

		return $value;

	}
}

/**
 * Get value from acf field
 */
if ( ! function_exists( 'hayley_get_field' ) ) {
	function hayley_get_field( $name = null, $postID = null ) {

		$value = null;

		// try get value from meta box
		if ( function_exists( 'get_field' ) ) {
			if ( $postID == null ) {
				$postID = get_the_ID();
			}
			$value = get_field( $name, $postID );
		}

		return $value;

	}
}

/**
 * Get social icons
 */
if ( ! function_exists( 'hayley_get_social_icons' ) ) {
	function hayley_get_social_icons() {
		$social_icons = array(
			'ion-social-android' => esc_html__( 'Android', 'hayley-raymond' ),
			'ion-social-angular' => esc_html__( 'Angular', 'hayley-raymond' ),
			'ion-social-apple' => esc_html__( 'Apple', 'hayley-raymond' ),
			'ion-social-bitcoin' => esc_html__( 'Bitcoin', 'hayley-raymond' ),
			'ion-social-buffer' => esc_html__( 'Buffer', 'hayley-raymond' ),
			'ion-social-chrome' => esc_html__( 'Chrome', 'hayley-raymond' ),
			'ion-social-codepen' => esc_html__( 'Codepen', 'hayley-raymond' ),
			'ion-social-css3' => esc_html__( 'CSS3', 'hayley-raymond' ),
			'ion-social-designernews' => esc_html__( 'Buffer', 'hayley-raymond' ),
			'ion-social-dribbble' => esc_html__( 'Dribbble', 'hayley-raymond' ),
			'ion-social-dropbox' => esc_html__( 'Dropbox', 'hayley-raymond' ),
			'ion-social-euro' => esc_html__( 'Euro', 'hayley-raymond' ),
			'ion-social-facebook' => esc_html__( 'Facebook', 'hayley-raymond' ),
			'ion-social-foursquare' => esc_html__( 'Foursquare', 'hayley-raymond' ),
			'ion-social-freebsd-devil' => esc_html__( 'Dreebsd Devil', 'hayley-raymond' ),
			'ion-social-github' => esc_html__( 'Github', 'hayley-raymond' ),
			'ion-social-google' => esc_html__( 'Google', 'hayley-raymond' ),
			'ion-social-googleplus' => esc_html__( 'GooglePlus', 'hayley-raymond' ),
			'ion-social-hackernews' => esc_html__( 'HackerNews', 'hayley-raymond' ),
			'ion-social-html5' => esc_html__( 'HTML5', 'hayley-raymond' ),
			'ion-social-instagram' => esc_html__( 'Instagram', 'hayley-raymond' ),
			'ion-social-javascript' => esc_html__( 'Javascript', 'hayley-raymond' ),
			'ion-social-linkedin' => esc_html__( 'LinkedIn', 'hayley-raymond' ),
			'ion-social-markdown' => esc_html__( 'Markdown', 'hayley-raymond' ),
			'ion-social-nodejs' => esc_html__( 'NodeJS', 'hayley-raymond' ),
			'ion-social-octocat' => esc_html__( 'Octocat', 'hayley-raymond' ),
			'ion-social-pinterest' => esc_html__( 'Pinterest', 'hayley-raymond' ),
			'ion-social-python' => esc_html__( 'Python', 'hayley-raymond' ),
			'ion-social-reddit' => esc_html__( 'Reddit', 'hayley-raymond' ),
			'ion-social-rss' => esc_html__( 'RSS', 'hayley-raymond' ),
			'ion-social-sass' => esc_html__( 'SASS', 'hayley-raymond' ),
			'ion-social-skype' => esc_html__( 'Skype', 'hayley-raymond' ),
			'ion-social-snapchat' => esc_html__( 'Snapchat', 'hayley-raymond' ),
			'ion-social-tumblr' => esc_html__( 'Tumblr', 'hayley-raymond' ),
			'ion-social-tux' => esc_html__( 'Tux', 'hayley-raymond' ),
			'ion-social-twitch' => esc_html__( 'Twitch', 'hayley-raymond' ),
			'ion-social-twitter' => esc_html__( 'Twitter', 'hayley-raymond' ),
			'ion-social-usd' => esc_html__( 'USD', 'hayley-raymond' ),
			'ion-social-vimeo' => esc_html__( 'Vimeo', 'hayley-raymond' ),
			'ion-social-whatsapp' => esc_html__( 'WhatsApp', 'hayley-raymond' ),
			'ion-social-windows' => esc_html__( 'Windows', 'hayley-raymond' ),
			'ion-social-wordpress' => esc_html__( 'WordPress', 'hayley-raymond' ),
			'ion-social-yahoo' => esc_html__( 'Yahoo', 'hayley-raymond' ),
			'ion-social-yen' => esc_html__( 'Yen', 'hayley-raymond' ),
			'ion-social-youtube' => esc_html__( 'YouTube', 'hayley-raymond' )
		);
		return apply_filters( 'hayley/get_social_icons', $social_icons );
	}
}

/**
 * Add custom choice
 */
if ( ! function_exists( 'hayley_add_custom_choice' ) ) {
	function hayley_add_custom_choice() {
		return array(
			'fonts' => array(
				'families' => array(
					'custom' => array(
						'text' => esc_html__( 'Hayley Fonts', 'hayley-raymond' ),
						'children' => array(
							array( 'id' => 'MonumentExtended', 'text' => 'MonumentExtended' ),
						),
					),
				),
			),
		);
	}
}

add_filter( 'elementor/fonts/groups', function( $font_groups ) {
	$font_groups['theme_fonts'] = esc_html__( 'Hayley Fonts', 'hayley-raymond' );
	return $font_groups;
} );

add_filter( 'elementor/fonts/additional_fonts', function( $additional_fonts ) {
	$additional_fonts['MonumentExtended'] = 'theme_fonts';
	return $additional_fonts;
} );