<?php

/**
 * @author: VLThemes
 * @version: 1.0
 */

/**
 * ACF in Admin Panel
 */
if ( ! function_exists( 'hayley_acf_in_admin_panel' ) ) {
	function hayley_acf_in_admin_panel() {
		return hayley_get_theme_mod( 'acf_show_admin_panel' ) == 'show' ? true : false;
	}
}
add_filter( 'hayley/acf_show_admin_panel', 'hayley_acf_in_admin_panel' );

/**
 * Add body class
 */
if ( ! function_exists( 'hayley_add_body_class' ) ) {
	function hayley_add_body_class( $classes ) {

		$classes[] = '';

		if ( ! wp_is_mobile() ) {
			$classes[] = 'no-mobile';
		} else {
			$classes[] = 'is-mobile';
		}

		return $classes;
	}
}
add_filter( 'body_class', 'hayley_add_body_class' );

/**
 * Add html class
 */
if ( ! function_exists( 'hayley_add_html_class' ) ) {
	function hayley_add_html_class( $classes = '' ) {
		$classes .= '';
		return apply_filters( 'hayley/add_html_class', hayley_sanitize_class( $classes ) );
	}
}

/**
 * Get post password form
 */
if ( ! function_exists( 'hayley_get_post_password_form' ) ) {
	function hayley_get_post_password_form() {
		global $post;
		$label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
		$output = '<form class="vlt-post-password-form" action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">';
		$output .= '<h4>' . esc_html__( 'Password Protected', 'hayley-raymond' ) . '</h4>';
		$output .= '<p>' . esc_html__( 'This content is restricted access, please type the password below and get access.', 'hayley-raymond' ) . '</p>';
		$output .= '<div class="vlt-form-group m-0">';
		$output .= '<input name="post_password" id="' . $label . '" type="password" size="20" class="vlt-form-control">';
		$output .= '<label for="' . $label . '" class="vlt-form-label">' . esc_attr__( 'Password:' , 'hayley-raymond' ) . '</label>';
		$output .= '<button><i class="ion-unlocked"></i></button>';
		$output .= '</div>';
		$output .= '</form>';
		return apply_filters( 'hayley/get_post_password_form', $output );
	}
}
add_filter( 'the_password_form', 'hayley_get_post_password_form' );

/**
 * Admin logo link
 */
if ( ! function_exists( 'hayley_change_admin_logo_link' ) ) {
	function hayley_change_admin_logo_link() {
		return home_url( '/' );
	}
}
add_filter( 'login_headerurl', 'hayley_change_admin_logo_link' );

/**
 * Comment form fields order
 */
if ( ! function_exists( 'hayley_comment_form_fields' ) ) {
	function hayley_comment_form_fields( $comment_fields ) {
		if ( hayley_get_theme_mod( 'comment_placement' ) == 'bottom' ) {
			$keys = array_keys( $comment_fields );
			if ( 'comment' == $keys[0] ) {
				$comment_fields['comment'] = array_shift( $comment_fields );
			}
		}
		return $comment_fields;
	}
}
add_filter( 'comment_form_fields', 'hayley_comment_form_fields' );

/**
 * Remove comment notes
 */
add_filter( 'comment_form_logged_in', '__return_empty_string' );

/**
 * Add comma to tag widget
 */
if ( ! function_exists( 'hayley_filter_tag_cloud' ) ) {
	function hayley_filter_tag_cloud( $args ) {
		$args['smallest'] = .75;
		$args['largest'] = .75;
		$args['unit'] = 'rem';
		$args['orderby'] = 'count';
		$args['order'] = 'DESC';
		$args['separator']= '';
		return $args;
	}
}
add_filter( 'widget_tag_cloud_args', 'hayley_filter_tag_cloud' );

/**
 * Remove cf7 autop
 */
add_filter( 'wpcf7_autop_or_not', '__return_false' );

add_filter( 'wpcf7_form_elements', function( $content ) {
	$content = preg_replace( '/<(span).*?class="\s*(?:.*\s)?wpcf7-form-control-wrap(?:\s[^"]+)?\s*"[^\>]*>(.*)<\/\1>/i', '\2', $content );
	$content = str_replace( '<br />', '', $content );
	return $content;
});